diff --git a/microfrontends/SignDocuments/src/Component/component/renderPdf.js b/microfrontends/SignDocuments/src/Component/component/renderPdf.js
index 2cef62af8..62aba99d1 100644
--- a/microfrontends/SignDocuments/src/Component/component/renderPdf.js
+++ b/microfrontends/SignDocuments/src/Component/component/renderPdf.js
@@ -42,8 +42,8 @@ function RenderPdf({
const isMobile = window.innerWidth < 767;
const newWidth = window.innerWidth;
const scale = isMobile ? pdfOriginalWidth / newWidth : 1;
- //check isSigner is present in local if yes than handle login flow header in mobile view
- const isSigner = localStorage.getItem("isSigner");
+ //check isGuestSigner is present in local if yes than handle login flow header in mobile view
+ const isGuestSigner = localStorage.getItem("isGuestSigner");
//function for render placeholder block over pdf document
@@ -239,7 +239,7 @@ function RenderPdf({
{
const clientWidth = window.innerWidth;
const pdfWidth = clientWidth - 160 - 220 - 30;
@@ -1011,8 +1011,8 @@ function EmbedPdfImage() {
{/* pdf render view */}
500 && "20px",
- marginRight: !isSigner && pdfOriginalWidth > 500 && "20px"
+ marginLeft: !isGuestSigner && pdfOriginalWidth > 500 && "20px",
+ marginRight: !isGuestSigner && pdfOriginalWidth > 500 && "20px"
}}
>
{/* this modal is used show this document is already sign */}